<img src="https://github.com/jtl125/perIOdico/blob/master/main_logo.png" width="400" align="right">

# perIOdico
Small program that obtains the front page of El Pais for a given date

## Installation and use

To install just type in the terminal:

```
pip install perIOdico
```

and simply use the command `perIOdico` in a terminal to run it.

## Future development

- Add a variety of newspapers as well as a country / region detection
- Create a twiter bot
